@@ -1,11 +1,9 @@
 package Tapper::Benchmark;
-# git description: v0.009-2-g6d68de4
-
 BEGIN {
   $Tapper::Benchmark::AUTHORITY = 'cpan:TAPPER';
 }
 # ABSTRACT: Autonomous SQL backend to store benchmarks
-$Tapper::Benchmark::VERSION = '0.010';
+$Tapper::Benchmark::VERSION = '0.011';
 use strict;
 use warnings;
 
@@ -352,7 +350,7 @@ sub enqueue_multi_benchmark {
 
     require Sereal::Encoder;
 
-    my $s_serialized = Sereal::Encoder->new({compress => 1})->encode($ar_data_points);
+    my $s_serialized = Sereal::Encoder->new->encode($ar_data_points);
     $or_self->{query}->insert_raw_bench_bundle($s_serialized);
 
     return 1;
@@ -369,7 +367,7 @@ sub process_queued_multi_benchmark {
     my $ar_data_points;
     my $ar_results;
     my $or_result;
-    my $driver = $or_self->{query}{driver};
+    my $driver = $or_self->{query}{dbh}{Driver}{Name};
 
     # ===== exclusively pick single raw entry =====
     # Lock single row via processing=1 so that only one worker handles it!
